@@ -15,12 +15,11 @@ package promql
 
 import (
 	"context"
-	"reflect"
+	"errors"
 	"testing"
 	"time"
 
 	"github.com/go-kit/kit/log"
-	"github.com/pkg/errors"
 
 	"github.com/prometheus/prometheus/pkg/labels"
 	"github.com/prometheus/prometheus/storage"
@@ -104,14 +103,14 @@ func TestQueryTimeout(t *testing.T) {
 	})
 
 	res := query.Exec(ctx)
-	if res.Err == nil {
-		t.Fatalf("expected timeout error but got none")
-	}
-	if _, ok := res.Err.(ErrQueryTimeout); res.Err != nil && !ok {
-		t.Fatalf("expected timeout error but got: %s", res.Err)
-	}
+	testutil.NotOk(t, res.Err, "expected timeout error but got none")
+
+	var e ErrQueryTimeout
+	testutil.Assert(t, errors.As(res.Err, &e), "expected timeout error but got: %s", res.Err)
 }
 
+const errQueryCanceled = ErrQueryCanceled("test statement execution")
+
 func TestQueryCancel(t *testing.T) {
 	opts := EngineOpts{
 		Logger:        nil,
@@ -146,12 +145,8 @@ func TestQueryCancel(t *testing.T) {
 	block <- struct{}{}
 	<-processing
 
-	if res.Err == nil {
-		t.Fatalf("expected cancellation error for query1 but got none")
-	}
-	if ee := ErrQueryCanceled("test statement execution"); res.Err != ee {
-		t.Fatalf("expected error %q, got %q", ee, res.Err)
-	}
+	testutil.NotOk(t, res.Err, "expected cancellation error for query1 but got none")
+	testutil.Equals(t, res.Err, errQueryCanceled)
 
 	// Canceling a query before starting it must have no effect.
 	query2 := engine.newTestQuery(func(ctx context.Context) error {
@@ -160,9 +155,7 @@ func TestQueryCancel(t *testing.T) {
 
 	query2.Cancel()
 	res = query2.Exec(ctx)
-	if res.Err != nil {
-		t.Fatalf("unexpected error on executing query2: %s", res.Err)
-	}
+	testutil.Ok(t, res.Err)
 }
 
 // errQuerier implements storage.Querier which always returns error.
@@ -203,28 +196,18 @@ func TestQueryError(t *testing.T) {
 	defer cancelCtx()
 
 	vectorQuery, err := engine.NewInstantQuery(queryable, "foo", time.Unix(1, 0))
-	if err != nil {
-		t.Fatalf("unexpected error creating query: %q", err)
-	}
+	testutil.Ok(t, err)
+
 	res := vectorQuery.Exec(ctx)
-	if res.Err == nil {
-		t.Fatalf("expected error on failed select but got none")
-	}
-	if res.Err != errStorage {
-		t.Fatalf("expected error %q, got %q", errStorage, res.Err)
-	}
+	testutil.NotOk(t, res.Err, "expected error on failed select but got none")
+	testutil.Equals(t, res.Err, errStorage)
 
 	matrixQuery, err := engine.NewInstantQuery(queryable, "foo[1m]", time.Unix(1, 0))
-	if err != nil {
-		t.Fatalf("unexpected error creating query: %q", err)
-	}
+	testutil.Ok(t, err)
+
 	res = matrixQuery.Exec(ctx)
-	if res.Err == nil {
-		t.Fatalf("expected error on failed select but got none")
-	}
-	if res.Err != errStorage {
-		t.Fatalf("expected error %q, got %q", errStorage, res.Err)
-	}
+	testutil.NotOk(t, res.Err, "expected error on failed select but got none")
+	testutil.Equals(t, res.Err, errStorage)
 }
 
 // paramCheckerQuerier implements storage.Querier which checks the start and end times
@@ -427,12 +410,8 @@ func TestEngineShutdown(t *testing.T) {
 	block <- struct{}{}
 	<-processing
 
-	if res.Err == nil {
-		t.Fatalf("expected error on shutdown during query but got none")
-	}
-	if ee := ErrQueryCanceled("test statement execution"); res.Err != ee {
-		t.Fatalf("expected error %q, got %q", ee, res.Err)
-	}
+	testutil.NotOk(t, res.Err, "expected error on shutdown during query but got none")
+	testutil.Equals(t, res.Err, errQueryCanceled)
 
 	query2 := engine.newTestQuery(func(context.Context) error {
 		t.Fatalf("reached query execution unexpectedly")
@@ -442,12 +421,10 @@ func TestEngineShutdown(t *testing.T) {
 	// The second query is started after the engine shut down. It must
 	// be canceled immediately.
 	res2 := query2.Exec(ctx)
-	if res2.Err == nil {
-		t.Fatalf("expected error on querying with canceled context but got none")
-	}
-	if _, ok := res2.Err.(ErrQueryCanceled); !ok {
-		t.Fatalf("expected cancellation error, got %q", res2.Err)
-	}
+	testutil.NotOk(t, res2.Err, "expected error on querying with canceled context but got none")
+
+	var e ErrQueryCanceled
+	testutil.Assert(t, errors.As(res2.Err, &e), "expected cancellation error but got: %s", res2.Err)
 }
 
 func TestEngineEvalStmtTimestamps(t *testing.T) {
@@ -455,15 +432,11 @@ func TestEngineEvalStmtTimestamps(t *testing.T) {
 load 10s
   metric 1 2
 `)
-	if err != nil {
-		t.Fatalf("unexpected error creating test: %q", err)
-	}
+	testutil.Ok(t, err)
 	defer test.Close()
 
 	err = test.Run()
-	if err != nil {
-		t.Fatalf("unexpected error initializing test: %q", err)
-	}
+	testutil.Ok(t, err)
 
 	cases := []struct {
 		Query       string
@@ -540,20 +513,16 @@ load 10s
 		} else {
 			qry, err = test.QueryEngine().NewRangeQuery(test.Queryable(), c.Query, c.Start, c.End, c.Interval)
 		}
-		if err != nil {
-			t.Fatalf("unexpected error creating query: %q", err)
-		}
+		testutil.Ok(t, err)
+
 		res := qry.Exec(test.Context())
 		if c.ShouldError {
 			testutil.NotOk(t, res.Err, "expected error for the query %q", c.Query)
 			continue
 		}
-		if res.Err != nil {
-			t.Fatalf("unexpected error running query: %q", res.Err)
-		}
-		if !reflect.DeepEqual(res.Value, c.Result) {
-			t.Fatalf("unexpected result for query %q: got %q wanted %q", c.Query, res.Value.String(), c.Result.String())
-		}
+
+		testutil.Ok(t, res.Err)
+		testutil.Equals(t, res.Value, c.Result)
 	}
 
 }
@@ -563,16 +532,11 @@ func TestMaxQuerySamples(t *testing.T) {
 load 10s
   metric 1 2
 `)
-
-	if err != nil {
-		t.Fatalf("unexpected error creating test: %q", err)
-	}
+	testutil.Ok(t, err)
 	defer test.Close()
 
 	err = test.Run()
-	if err != nil {
-		t.Fatalf("unexpected error initializing test: %q", err)
-	}
+	testutil.Ok(t, err)
 
 	cases := []struct {
 		Query      string
@@ -772,16 +736,11 @@ load 10s
 		} else {
 			qry, err = engine.NewRangeQuery(test.Queryable(), c.Query, c.Start, c.End, c.Interval)
 		}
-		if err != nil {
-			t.Fatalf("unexpected error creating query: %q", err)
-		}
+		testutil.Ok(t, err)
+
 		res := qry.Exec(test.Context())
-		if res.Err != nil && res.Err != c.Result.Err {
-			t.Fatalf("unexpected error running query: %q, expected to get result: %q", res.Err, c.Result.Value)
-		}
-		if !reflect.DeepEqual(res.Value, c.Result.Value) {
-			t.Fatalf("unexpected result for query %q: got %q wanted %q", c.Query, res.Value.String(), c.Result.String())
-		}
+		testutil.Equals(t, res.Err, c.Result.Err)
+		testutil.Equals(t, res.Value, c.Result.Value)
 	}
 }
 
@@ -1048,16 +1007,12 @@ func TestSubquerySelector(t *testing.T) {
 	SetDefaultEvaluationInterval(1 * time.Minute)
 	for _, tst := range tests {
 		test, err := NewTest(t, tst.loadString)
+		testutil.Ok(t, err)
 
-		if err != nil {
-			t.Fatalf("unexpected error creating test: %q", err)
-		}
 		defer test.Close()
 
 		err = test.Run()
-		if err != nil {
-			t.Fatalf("unexpected error initializing test: %q", err)
-		}
+		testutil.Ok(t, err)
 
 		engine := test.QueryEngine()
 		for _, c := range tst.cases {
@@ -1065,16 +1020,11 @@ func TestSubquerySelector(t *testing.T) {
 			var qry Query
 
 			qry, err = engine.NewInstantQuery(test.Queryable(), c.Query, c.Start)
-			if err != nil {
-				t.Fatalf("unexpected error creating query: %q", err)
-			}
+			testutil.Ok(t, err)
+
 			res := qry.Exec(test.Context())
-			if res.Err != nil && res.Err != c.Result.Err {
-				t.Fatalf("unexpected error running query: %q, expected to get result: %q", res.Err, c.Result.Value)
-			}
-			if !reflect.DeepEqual(res.Value, c.Result.Value) {
-				t.Fatalf("unexpected result for query %q: got %q wanted %q", c.Query, res.Value.String(), c.Result.String())
-			}
+			testutil.Equals(t, res.Err, c.Result.Err)
+			testutil.Equals(t, res.Value, c.Result.Value)
 		}
 	}
 }
